- y
A numeric vector of the response variable.
- x
A numeric vector or matrix of the input variables.
- sep
Logical indicator for using a separable kernel function (sep=TRUE) or an isotropic kernel function (sep=FALSE).
Default is TRUE.
- mu
Logical indicator for assuming zero mean (mu=FALSE) or estimating the mean (mu=TRUE).
Default is FALSE (assumes the data is centered beforehand).
- g
Logical indicator for fixing the nugget value to a small constant (g=FALSE) or estimating the nugget (g=TRUE). Default is FALSE.
- fixed_g
Nugget value to fix when g=FALSE. Default is fixed_g=NULL. If NULL, the nugget is fixed to 1.490116e-08.
- profile
Logical indicator for optimizing the profile log-likelihood (profile=TRUE). When TRUE, the log-likelihood is a function of lengthscale and nugget only.
Solve the closed forms for scale and mu parameters. When FALSE, the full log-likelihood is optimized (lengthscale, scale, mean, and nugget are estimated together). Default is TRUE.
- initialvals
A numeric vector or matrix of initial values for optimization. The length should match the number of parameters to estimate.
Default is NULL. If NULL, 10 sets of initial values are randomly generated. The number of sets can be specified by specifying n_init.
- n_init
An integer indicating the number of randomly generated initial value sets to evaluate when initialvals is not provided.
Default is 10.
- penalty
Logical indicator for penalization. Default is penalty=FALSE (returns MLE). When penalty=TRUE and no lambda value is specified, a set of estimated values along with evaluated lambda values is returned.
- scad
Logical indicator for a lasso penalty (scad=FALSE) or SCAD penalty (scad=TRUE) when penalty=TRUE. Default is lasso penalty.
- lambda
Tuning parameter value. Default is 0 (MLE). The user may specify a custom lambda value.
- theta_upper
Upper bound for theta in optim. Default is 1000.
- theta_lower
Lower bound for theta in optim. Default is 0.001.
- ncores
A number of cores for parallel computing with optim. Default is 1. Make sure your system supports the specified number of cores.